<?php
/**
 * Upload a single image
 */
function _upload(&$tof,$vars) {
	require_once("actions/roll.php");
	require_once("actions/topic.php");
	require_once("actions/uploads.php");

	// TODO: We should check $_FILES['file']['error']
	$rollID = maybeCreateRoll($tof,$vars['NewRollID'],$vars['RollID']);
	$topicID = maybeCreateTopic(
		$tof,
		$vars['ParentTopicID'],
		$vars['NewTopicDescription'],
		array(EVERYBODY),
		array(READ,WRITE));

	uploadFile(
		$tof,
		$_FILES['file']['tmp_name'],
		$_FILES['file']['name'],
		$_FILES['file']['size'],
		$_FILES['file']['type'],
		$vars['FrameID'],
		$rollID,
		$topicID,
		$vars['Description'],
		$vars['Groups']);
}
?>